package sdl4gcj;

import sdl4gcj.cdrom.CDConstants;
import sdl4gcj.event.EventConstants;
import sdl4gcj.input.JoystickConstants;
import sdl4gcj.input.KeyboardConstants;
import sdl4gcj.input.MouseConstants;
import sdl4gcj.video.VideoConstants;

public interface SDLConstants extends SysConstants,
	EventConstants, CDConstants, JoystickConstants,
	KeyboardConstants, MouseConstants, VideoConstants
{
	int SDL_LIL_ENDIAN = 1234;
	int SDL_BIG_ENDIAN = 4321;
}
